@@ -1,9 +1,9 @@
 make_QP_signatures <- function() {
-    .ROI_plugin_make_signature( objective = "Q",
+    ROI_plugin_make_signature( objective = "Q",
                         constraints = c("X", "L"),
                         types = c("C"),
                         bounds = c("X", "V"),
-                        cones = c("free"),
+                        cones = c("X"),
                         maximum = c(TRUE, FALSE) )
 }
 
@@ -13,8 +13,8 @@ make_QP_signatures <- function() {
     if( ! pkgname %in% ROI_registered_solvers() ){
         ## Register solver methods here.
         ## One can assign several signatures a single solver method
-        solver <- .ROI_plugin_get_solver_name( pkgname )
-        .ROI_plugin_register_solver_method( signatures = make_QP_signatures(),
+        solver <- ROI_plugin_get_solver_name( pkgname )
+        ROI_plugin_register_solver_method( signatures = make_QP_signatures(),
                                             solver = solver,
                                             method =
             getFunction( "solve_QP", where = getNamespace(pkgname)) )
@@ -24,5 +24,5 @@ make_QP_signatures <- function() {
 }
 
 #.onUnload <- function( libpath ){
-#    .ROI_plugin_deregister_solver_methods( solver = "glpk" )
+#    ROI_plugin_deregister_solver_methods( solver = "glpk" )
 #}
